@@ -34,6 +34,10 @@ class PaymentSubTypes(str, Enum):
     cod = "cod"
     offline = "offline"
     linepay = "linepay"
+    barcode = "barcode"
+    webatm = "webatm"
+    cvs = "cvs"
+    unknown = "unknown"
 
 
 class LogisticTypes(str, Enum):
@@ -48,6 +52,15 @@ class HomeSubtypes(str, Enum):
     TCAT = "TCAT"
 
 
+class InvoiceTypes(str, Enum):
+    B2B = "B2B"
+    B2C = "B2C"
+    B2C_DONATE = "B2C_DONATE"
+    B2C_PHONE_CARRIER = "B2C_PHONE_CARRIER"
+    B2C_NPC = "B2C_NPC"
+    B2C_PROVIDER = "B2C_PROVIDER"
+
+
 class CVSLogisticSubTypes(str, Enum):
     FAMI = "FAMI"
     UNIMART = "UNIMART"
@@ -60,41 +73,36 @@ class CVSLogisticSubTypes(str, Enum):
 
 class CartConfig(BaseCartConfig):
     buyer_name: str = ""
-    buyer_phone: Optional[str] = ""
+    buyer_phone: str = ""
     buyer_email: EmailStr
-    buyer_zip: Optional[str] = ""
-    buyer_city: Optional[str] = ""
-    buyer_district: Optional[str] = ""
-    buyer_address: Optional[str] = ""
-    buyer_tel: Optional[str] = ""
-    buyer_tel_ext: Optional[str] = ""
-    receiver_name: Optional[str] = ""
-    receiver_phone: Optional[str] = ""
-    receiver_email: Optional[str] = ""
-    receiver_zip: Optional[str] = ""
-    receiver_city: Optional[str] = ""
-    receiver_district: Optional[str] = ""
-    receiver_address: Optional[str] = ""
-    receiver_tel: Optional[str] = ""
-    receiver_tel_ext: Optional[str] = ""
+    buyer_zip: str = ""
+    buyer_city: str = ""
+    buyer_district: str = ""
+    buyer_address: str = ""
+    buyer_tel: str = ""
+    buyer_tel_ext: str = ""
+    receiver_name: str = ""
+    receiver_phone: str = ""
+    receiver_email: str = ""
+    receiver_zip: str = ""
+    receiver_city: str = ""
+    receiver_district: str = ""
+    receiver_address: str = ""
+    receiver_tel: str = ""
+    receiver_tel_ext: str = ""
     payment_subtype: PaymentSubTypes = PaymentSubTypes.credit
     logistics_type: LogisticTypes = LogisticTypes.CVS
     logistics_subtype: str = CVSLogisticSubTypes.FAMIC2C
     logistics_cvs_store_id: Optional[str]
-    # 1: 應稅 2: 零稅率 3: 免稅 4: 特種應稅 9: 混合稅（限B2C）
-    invoice_tax_type: Literal["1", "2", "3", "4", "9"] = "1"
-    invoice_tax_rate: float = 0.05
-    # B2B 統編
-    invoice_uni_no: Optional[str]
-    invoice_category: Literal["B2B", "B2C"] = "B2C"
-    # B2C 是否捐贈
-    invoice_donation: Literal["0", "1"] = "0"
-    # B2C 捐贈碼
-    invoice_love_code: Optional[str]
-    # B2C 載具類型 0: 無載具 1: 綠界電子發票（使用者email-優先 or phone） 2: 自然人憑證 3: 手機條碼
-    invoice_carrier_type: Literal["0", "1", "2", "3"] = "1"
-    # B2C 載具編號 如果 carrier_type = "1" 載具編號放空字串即可， ecpay 會拿 customer email or phone
-    invoice_carrier_num: str = ""
+
+    invoice_type: InvoiceTypes = InvoiceTypes.B2C
+    b2b_company_name: str = ""
+    b2b_company_no: str = ""
+    b2c_phone_carrier_code: str = ""
+    b2c_donate_code: str = ""
+    b2c_npc_code: str = ""
+    b2c_provider_code: str = ""
+
     order_note: str = ""
     points: int = 0
     gift_points: int = 0
@@ -212,6 +220,9 @@ class Product(BaseModel):
     images: Optional[Union[List[str], List[Dict[str, Any]]]]
     extra_data: Optional[Any]
 
+    class Config:
+        allow_population_by_field_name = True
+
 
 class Coupon(BaseModel):
     id: ValidatedObjectId = Field(alias="_id")
